@@ -1,5 +1,5 @@
 from PyQt5.QtWidgets import QLabel, QSizePolicy, QVBoxLayout,QHBoxLayout,QGridLayout, QWidget, QScrollArea, QGroupBox, QMainWindow, QScrollBar, QApplication
-import Sim
+import Encrypt_Lab.Sim
 
 import sys
 
@@ -17,3 +17,4 @@ class Simulator:
 
         sys.exit(app.exec_())
 
+# Simulator.run()
\ No newline at end of file
